@@ -11,6 +11,7 @@ import org.gcube.portlets.widgets.ckan2zenodopublisher.client.view.Ckan2ZenodoVi
 import org.gcube.portlets.widgets.ckan2zenodopublisher.client.view.FormValidator;
 import org.gcube.portlets.widgets.ckan2zenodopublisher.client.view.LoaderIcon;
 import org.gcube.portlets.widgets.ckan2zenodopublisher.shared.CatalogueItem;
+import org.gcube.portlets.widgets.ckan2zenodopublisher.shared.ZenodoError;
 import org.gcube.portlets.widgets.ckan2zenodopublisher.shared.wrapped.ZenodoItem;
 
 import com.github.gwtbootstrap.client.ui.Alert;
@@ -89,7 +90,8 @@ public class CkanToZendoPublisherWidget {
 				Alert erroLabel = new Alert();
 				//erroLabel.setClose(false);
 				erroLabel.setType(AlertType.ERROR);
-				erroLabel.setText(caught.getLocalizedMessage());
+				String message = getErrorMessage(caught);
+				erroLabel.setText(message);
 				showResults(Arrays.asList(erroLabel.asWidget()));
 			}
 
@@ -99,6 +101,25 @@ public class CkanToZendoPublisherWidget {
 				modal.remove(loader);
 				manager = new Ckan2ZenodoViewManager();
 				basicTabPanel = manager.viewForPublishing(result);
+				//In case of error on translating it shows an alert
+				GWT.log("Translate Error is: "+result.getTranslateError());
+				if(result.getTranslateError()!=null) {
+					Alert alert = new Alert(result.getTranslateError().getError());
+					alert.setClose(true);
+					switch (result.getTranslateError().getErrorType()) {
+					case INFO:
+						alert.setType(AlertType.INFO);
+						break;
+					case WARN:
+						alert.setType(AlertType.WARNING);		
+						break;
+					case ERROR:
+					default:
+						alert.setType(AlertType.ERROR);		
+						break;
+					}
+					modal.add(alert);
+				}
 				modal.add(basicTabPanel);
 				buttonPublish.setEnabled(true);
 			}
@@ -152,24 +173,7 @@ public class CkanToZendoPublisherWidget {
 							Alert erroLabel = new Alert();
 							//erroLabel.setClose(false);
 							erroLabel.setType(AlertType.ERROR);
-							String message = caught.getLocalizedMessage();
-							try {
-								//Trying to parse the JSON object to display only the message
-								JSONValue value = JSONParser.parseStrict(message);
-								GWT.log("value: "+value.toString());
-								JSONObject jsonObject = value.isObject();
-								if(jsonObject!=null) {
-									JSONArray array = (JSONArray) jsonObject.get("errors");
-									//GWT.log("array: "+array.toString());
-									JSONObject theErrorValue = (JSONObject) array.get(0);
-									//GWT.log("theErrorValue: "+theErrorValue.toString());
-									JSONValue theMessage = theErrorValue.get("message");
-									//GWT.log("message: "+message.toString());
-									message = "Error reported from Zenodo: " + theMessage.toString();
-								}
-							}catch (Exception e) {
-								//silent
-							}
+							String message = getErrorMessage(caught);
 							erroLabel.setText(message);
 							showResults(Arrays.asList(erroLabel.asWidget()));
 						}
@@ -209,6 +213,52 @@ public class CkanToZendoPublisherWidget {
 	}
 	
 	
+
+	/**
+	 * Gets the error message.
+	 *
+	 * @param caught the caught
+	 * @return the error message
+	 */
+	public String getErrorMessage(Throwable caught) {
+		
+		String message = caught.getLocalizedMessage();
+		
+		if(caught instanceof ZenodoError) {
+			GWT.log("Caught is instanceof "+ZenodoError.class.getName());
+			try {
+				//Trying to parse the JSON object to display only the message
+				JSONValue value = JSONParser.parseStrict(((ZenodoError) caught).getRemoteMessage());
+				GWT.log("value: "+value.toString());
+				JSONObject jsonObject = value.isObject();
+				if(jsonObject!=null) {
+					JSONObject theErrorJSON = jsonObject;
+					if(jsonObject.isArray() != null) {
+						JSONArray array = (JSONArray) jsonObject.get("errors");
+						//GWT.log("array: "+array.toString());
+						theErrorJSON = (JSONObject) array.get(0);
+					}
+					
+					JSONValue theMessage = theErrorJSON.get("message");
+					return "Error reported from Zenodo: " + theMessage.toString();
+	
+//					//GWT.log("array: "+array.toString());
+//					JSONObject theErrorValue = (JSONObject) array.get(0);
+//					//GWT.log("theErrorValue: "+theErrorValue.toString());
+//					JSONValue theMessage = theErrorValue.get("message");
+//					//GWT.log("message: "+message.toString());
+//					return "Error reported from Zenodo: " + theMessage.toString();
+				}
+			}catch (Exception e) {
+				return message;
+			}
+		}
+		
+		return message;
+		
+	}
+	
+	
 	/**
 	 * Show results.
 	 *
